@@ -30,6 +30,7 @@ my $NAME = [
 	qr/Ilya/,
 	qr/Ivan/,
 	qr/Kirill/,
+	qr/kostya/,
 	qr/Konstantin/,
 	qr/Maxim\b/,
 	qr/Mishka/,
@@ -76,7 +77,7 @@ print
 		
 		# ru
 		grep { $_->{'pause'} eq 'STEALTHY' and $_->{'author'}=0; 1}
-		grep { $_->{'pause'} !~ /^AGNISLAV|ZERO|ZWON|SODASODA|CUB|DZHARIY|IHEFFNER|QUEVLAR|VTI|GUGU|EJS|GRUBER|EGORSH|MVUETS|BEROV|CYBER|NIKIP|TTOD|OMEGA|DRINCHEV|YAKWOO|PLCGI|MADZ|VMS|SHTATLAND|IVAN|ILYA|GREGORY|ERIC|DIMRUB|ANDREI|AXS|MOO|ICHLADIL|IZUT|IKETRIS|IVANS|ITUB|IVANWILLS|IVANWONG|PAVELH|INITDOTD|RUSSOZ$/ }
+		grep { $_->{'pause'} !~ /^KORSHAK|AGNISLAV|ZERO|ZWON|SODASODA|CUB|DZHARIY|IHEFFNER|QUEVLAR|VTI|GUGU|EJS|GRUBER|EGORSH|MVUETS|BEROV|CYBER|NIKIP|TTOD|OMEGA|DRINCHEV|YAKWOO|PLCGI|MADZ|VMS|SHTATLAND|IVAN|ILYA|GREGORY|ERIC|DIMRUB|ANDREI|AXS|MOO|ICHLADIL|IZUT|IKETRIS|IVANS|ITUB|IVANWILLS|IVANWONG|PAVELH|INITDOTD|RUSSOZ$/ }
 		
 		grep { $_->{'email'} !~ /ua$/ }
 		grep { $_->{'email'} !~ /bg$/ }
